@@ -2,11 +2,7 @@ from zope.interface import Interface
 from plone.theme.interfaces import IDefaultPloneLayer
 
 class IDropdownSpecific(IDefaultPloneLayer):
-    """Marker interface that defines a Zope 3 skin layer bound to a Skin
-       Selection in portal_skins.
-       If you need to register a viewlet only for the "Everest Poker Theme"
-       skin, this is the interface that must be used for the layer attribute
-       in everestPokerTheme/browser/configure.zcml.
+    """Marker interface that defines a Zope 3 browser layer.
     """
 
 class IDropdownMenuViewlet(Interface):
